@@ -25,6 +25,8 @@
 
 #include <KConfigDialog>
 
+#include <memory>
+
 namespace Ui {
 class Config;
 }
@@ -39,13 +41,13 @@ class ConfigDialog : public KConfigDialog
     Q_OBJECT
 
 public:
-    ConfigDialog(QWidget* parent);
-    virtual ~ConfigDialog();
+    explicit ConfigDialog(QWidget* parent);
+    ~ConfigDialog() override;
 
     static bool isShown();
 
 private:
-    QScopedPointer<Ui::Config> m_ui;
+    std::unique_ptr<Ui::Config> m_ui;
 };
 
 }
