@@ -27,10 +27,12 @@
 #include <QUrl>
 #include <QTemporaryFile>
 
-#include <KFilterDev>
+#include <KCompressionDevice>
 #include <KIO/FileCopyJob>
 #include <KLocalizedString>
 
+#include <memory>
+
 namespace Massif {
 
 ParseWorker::ParseWorker(QObject* parent)
@@ -61,7 +63,7 @@ void ParseWorker::parse(const QUrl& url, const QStringList& allocators)
         filePath = url.toLocalFile();
     }
 
-    KFilterDev device(filePath);
+    KCompressionDevice device(filePath);
     if (!device.open(QIODevice::ReadOnly)) {
         emit error(i18n("Read Failed"),
                    i18n("Could not open file <i>%1</i> for reading.", filePath));
@@ -71,7 +73,7 @@ void ParseWorker::parse(const QUrl& url, const QStringList& allocators)
     Parser p;
     emit progressRange(0, 100);
     connect(&p, &Parser::progress, this, &ParseWorker::progress);
-    QScopedPointer<FileData> data(p.parse(&device, allocators, &m_shouldStop));
+    std::unique_ptr<FileData> data(p.parse(&device, allocators, &m_shouldStop));
 
     if (!data) {
         if (!m_shouldStop) {
@@ -83,15 +85,15 @@ void ParseWorker::parse(const QUrl& url, const QStringList& allocators)
         }
         return;
     } else if (data->snapshots().isEmpty()) {
-        emit error(i18n("Empty data file <i>%1</i>.", url.toString()),
-                   i18n("Empty Data File"));
+        emit error(i18n("Empty Data File"),
+                   i18n("Empty data file <i>%1</i>.", url.toString()));
         return;
     }
 
     emit progress(100);
 
     // success!
-    emit finished(url, data.take());
+    emit finished(url, data.release());
 }
 
 void ParseWorker::stop()
@@ -100,3 +102,5 @@ void ParseWorker::stop()
 }
 
 }
+
+#include "moc_parseworker.cpp"
