@@ -28,6 +28,7 @@
 #include "massifdata/util.h"
 
 #include <QTextStream>
+#include <QRegExp>
 #include <QFile>
 #include <QColor>
 #include <QDebug>
@@ -42,7 +43,7 @@ struct GraphNode {
     // incoming calls + cost
     QHash<GraphNode*, quint64> children;
     // outgoing calls
-    QVector<GraphNode*> parents;
+    QList<GraphNode*> parents;
     quint64 accumulatedCost;
     bool visited;
     quint32 belowThresholdCount;
@@ -68,7 +69,7 @@ DotGraphGenerator::DotGraphGenerator(const SnapshotItem* snapshot, const QString
 
 DotGraphGenerator::DotGraphGenerator(const TreeLeafItem* node, const QString& timeUnit, QObject* parent)
     : QThread(parent)
-    , m_snapshot(0)
+    , m_snapshot(nullptr)
     , m_node(node)
     , m_canceled(false)
     , m_timeUnit(timeUnit)
@@ -121,7 +122,7 @@ QString getColor(quint64 cost, quint64 maxCost)
 }
 
 GraphNode* buildGraph(const TreeLeafItem* item, QMultiHash<QByteArray, GraphNode*>& knownNodes,
-                      quint64& maxCost, GraphNode* parent = 0)
+                      quint64& maxCost, GraphNode* parent = nullptr)
 {
     // merge below-threshold items
     if (parent && item->children().isEmpty()) {
@@ -131,9 +132,9 @@ GraphNode* buildGraph(const TreeLeafItem* item, QMultiHash<QByteArray, GraphNode
             parent->belowThresholdCost += item->cost();
             parent->belowThresholdCount += matchBT.cap(1).toInt();
         }
-        return 0;
+        return nullptr;
     }
-    GraphNode* node = knownNodes.value(item->label(), 0);
+    GraphNode* node = knownNodes.value(item->label(), nullptr);
     if (!node) {
         node = new GraphNode;
         knownNodes.insert(item->label(), node);
@@ -160,7 +161,7 @@ GraphNode* buildGraph(const TreeLeafItem* item, QMultiHash<QByteArray, GraphNode
             // was below-threshold item
             continue;
         }
-        QMultiHash< GraphNode*, quint64 >::iterator it = node->children.find(childNode);
+        auto it = node->children.find(childNode);
         if (it != node->children.end()) {
             it.value() += child->cost();
         } else {
@@ -289,7 +290,7 @@ void DotGraphGenerator::nodeToDot(GraphNode* node, QTextStream& out, const QStri
         return;
     }
 
-    QMultiHash< GraphNode*, quint64 >::const_iterator it = node->children.constBegin();
+    auto it = node->children.constBegin();
     while(it != node->children.constEnd()) {
         if (m_canceled) {
             return;
@@ -317,3 +318,5 @@ QString DotGraphGenerator::mostCostIntensiveGraphvizId() const
 {
     return m_costlyGraphvizId;
 }
+
+#include "moc_dotgraphgenerator.cpp"
